@@ -1,15 +1,18 @@
 from .instances import InstancesAPI
-from .metadata import MetadataAPI
+from .metadata import MetadataAPI, RealtoMetadataAPI
 from .timeseries import TimeseriesAPI
 from .periods import PeriodsAPI
 from .period_instances import PeriodInstancesAPI
 from .ohlc import OhlcAPI
+from .srmc import SrmcAPI
 
 __all__ = [
     "InstancesAPI",
     "MetadataAPI",
+    "RealtoMetadataAPI",
     "TimeseriesAPI",
     "PeriodsAPI",
     "PeriodInstancesAPI",
     "OhlcAPI",
+    "SrmcAPI",
 ]
\ No newline at end of file
