@@ -1,3 +1,6 @@
+# pylint: disable=pylint-enums-no-annotated-value
+# pylint: disable=protected-access
+# pylint: disable=too-many-instance-attributes
 import enum
 
 
@@ -5,6 +8,7 @@ class Allocation(enum.Enum):
     """
     Enumerator of border allocation types between two price areas.
     """
+
     #: Explicit exchange border
     EXPLICIT = ("E", "Explicit")
     #: Implicit exchange border
@@ -19,10 +23,16 @@ class Allocation(enum.Enum):
         self.label = label
 
     def __repr__(self):
-        return self.name
+        return self.tag
 
     def __str__(self):
-        return self.name
+        return self.tag
+
+    def __lt__(self, other):
+        return self.tag.__lt__(other.tag)
+
+    def __gt__(self, other):
+        return self.tag.__gt__(other.tag)
 
 
 class Area:
@@ -131,7 +141,7 @@ class Area:
         #: smaller areas)
         self.children = set()
         # Convert tag to variable name ("-" becomes "_")
-        self._variable = self.tag.replace('-', '_')
+        self._variable = self.tag.replace("-", "_")
         setattr(Area, self.tag.replace("-", "_"), self)
 
     _ordering_nb = []
@@ -161,6 +171,12 @@ class Area:
     def __str__(self):
         return "<Area: %s>" % self.tag
 
+    def __lt__(self, other):
+        return self.tag.__lt__(other.tag)
+
+    def __gt__(self, other):
+        return self.tag.__gt__(other.tag)
+
     def _add_exchange_neighbours(self, *neighbours):
         """
         Private method. Add a list of exchange neighbours to self and
@@ -269,6 +285,9 @@ class Border:
     def __eq__(self, other):
         return self.as_tuple() == other.as_tuple()
 
+    def __ne__(self, other):
+        return self.as_tuple() != other.as_tuple()
+
     def __repr__(self):
         return "<Border: %s – %s, allocations=%s>" % (
             self.source.tag,
@@ -331,7 +350,9 @@ DE = Area(tag="DE", name="Germany", country=True, price_area=True)
 DE_50Hertz = Area(tag="DE-50Hertz", name="Germany – 50Hertz", control_area=True)
 DE_Amprion = Area(tag="DE-Amprion", name="Germany – Amprion", control_area=True)
 DE_TenneT = Area(tag="DE-TenneT", name="Germany – TenneT GER", control_area=True)
-DE_TransnetBW = Area(tag="DE-TransnetBW", name="Germany – TransnetBW", control_area=True)
+DE_TransnetBW = Area(
+    tag="DE-TransnetBW", name="Germany – TransnetBW", control_area=True
+)
 DE._add_children(DE_50Hertz, DE_Amprion, DE_TenneT, DE_TransnetBW)
 
 FR = Area(tag="FR", name="France", country=True, price_area=True)
@@ -377,8 +398,15 @@ CH = Area(tag="CH", name="Switzerland", country=True, price_area=True)
 GB = Area(tag="GB", name="Great Britain", country=True, price_area=True)
 
 # Single Electricity Market (IE + NIE). IE = EirGrid. NIE = SONI.
-SEM = Area(tag="SEM", name="Single Electricity Market – Ireland", country=False, price_area=True)
-NIE = Area(tag="NIE", name="Northern Ireland", country=True, price_area=True, control_area=True)
+SEM = Area(
+    tag="SEM",
+    name="Single Electricity Market – Ireland",
+    country=False,
+    price_area=True,
+)
+NIE = Area(
+    tag="NIE", name="Northern Ireland", country=True, price_area=True, control_area=True
+)
 IE = Area(tag="IE", name="Ireland", country=True, price_area=True, control_area=True)
 SEM._add_children(NIE, IE)
 
@@ -401,13 +429,13 @@ PT = Area(tag="PT", name="Portugal", country=True, price_area=True)
 
 IT = Area(tag="IT", name="Italy", country=True, price_area=True)
 IT_NORD = Area(tag="IT-NORD", name="Italy – Northern", price_area=True)
-IT_SUD = Area(tag="IT-SUD", name="Italy – Southern", price_area=True)
 IT_CNOR = Area(tag="IT-CNOR", name="Italy – Central-Northern", price_area=True)
 IT_CSUD = Area(tag="IT-CSUD", name="Italy – Central-Southern", price_area=True)
+IT_SUD = Area(tag="IT-SUD", name="Italy – Southern", price_area=True)
+IT_CALA = Area(tag="IT-CALA", name="Italy – Calabria", price_area=True)
 IT_SARD = Area(tag="IT-SARD", name="Italy – Sardegna", price_area=True)
 IT_SICI = Area(tag="IT-SICI", name="Italy – Sicily", price_area=True)
-IT_CALA = Area(tag="IT-CALA", name="Italy – Calabria", price_area=True)
-IT._add_children(IT_NORD, IT_SUD, IT_CNOR, IT_CSUD, IT_SARD, IT_SICI)
+IT._add_children(IT_NORD, IT_CNOR, IT_CSUD, IT_SUD, IT_CALA, IT_SARD, IT_SICI)
 
 
 SI = Area(tag="SI", name="Slovenia", country=True, price_area=True)
@@ -420,6 +448,7 @@ BG = Area(tag="BG", name="Bulgaria", country=True, price_area=True)
 AL = Area(tag="AL", name="Albania", country=True, price_area=True)
 MK = Area(tag="MK", name="North Macedonia", country=True, price_area=True)
 GR = Area(tag="GR", name="Greece", country=True, price_area=True)
+XK = Area(tag="XK", name="Kosovo", country=True, control_area=True)
 
 
 ## South-Eastern Europe
@@ -440,7 +469,7 @@ MT = Area(tag="MT", name="Malta", country=True, external=True)
 ## Nordic borders
 
 NO1._add_borders((NO2, "I"), (NO3, "I"), (NO5, "I"), (SE3, "I"))
-NO2._add_borders((DE, "I"), (DK1, "I"), (NL, "I"), (NO1, "I"), (NO5, "I"))
+NO2._add_borders((DE, "I"), (DK1, "I"), (GB, "E"), (NL, "I"), (NO1, "I"), (NO5, "I"))
 NO3._add_borders((NO1, "I"), (NO4, "I"), (NO5, "I"), (SE2, "I"))
 NO4._add_borders((FI, "N"), (NO3, "I"), (SE1, "I"), (SE2, "I"))
 NO5._add_borders((NO1, "I"), (NO2, "I"), (NO3, "I"))
@@ -469,38 +498,38 @@ DE._add_borders(
     (AT, "F"),
     (BE, "F"),
     (CH, "E"),
-    (CZ, "E"),
+    (CZ, "EI"),
     (DK1, "I"),
     (DK2, "I"),
     (FR, "F"),
     (NL, "F"),
     (NO2, "I"),
-    (PL, "E"),
+    (PL, "EI"),
     (SE4, "I"),
 )
-AT._add_borders((CH, "E"), (CZ, "E"), (DE, "F"), (HU, "E"), (IT_NORD, "EI"), (SI, "EI"))
+AT._add_borders((CH, "E"), (CZ, "EI"), (DE, "F"), (HU, "EI"), (IT_NORD, "EI"), (SI, "EI"))
 FR._add_borders(
-    (BE, "F"), (CH, "E"), (DE, "F"), (ES, "EI"), (GB, "EI"), (IT_NORD, "EI")
+    (BE, "F"), (CH, "E"), (DE, "F"), (ES, "EI"), (GB, "E"), (IT_NORD, "EI")
 )
 FR_COR._add_borders((IT_SARD, "I"))
-NL._add_borders((BE, "F"), (DE, "F"), (DK1, "I"), (GB, "EI"), (NO2, "I"))
-BE._add_borders((DE, "F"), (FR, "F"), (GB, "EI"), (NL, "F"))
+NL._add_borders((BE, "F"), (DE, "F"), (DK1, "I"), (GB, "E"), (NO2, "I"))
+BE._add_borders((DE, "F"), (FR, "F"), (GB, "E"), (NL, "F"))
 CH._add_borders((AT, "E"), (DE, "E"), (FR, "E"), (IT_NORD, "E"))
 
 
 ## United Kingdom/Ireland
 
-GB._add_borders((BE, "EI"), (FR, "EI"), (NL, "EI"), (NIE, "I"), (IE, "I"))
+GB._add_borders((BE, "E"), (FR, "E"), (NL, "E"), (NIE, "I"), (IE, "I"), (NO2, "E"))
 NIE._add_borders((IE, "I"), (GB, "I"))
 IE._add_borders((NIE, "I"), (GB, "I"))
 
 
 ## Central Eastern Europe
 
-PL._add_borders((CZ, "E"), (DE, "E"), (LT, "I"), (SE4, "I"), (SK, "E"), (UA, "E"))
-CZ._add_borders((AT, "E"), (DE, "E"), (PL, "E"), (SK, "EI"))
-HU._add_borders((AT, "E"), (HR, "E"), (RO, "EI"), (RS, "E"), (SK, "EI"), (UA, "E"))
-SK._add_borders((CZ, "EI"), (HU, "EI"), (PL, "E"), (UA, "E"))
+PL._add_borders((CZ, "EI"), (DE, "EI"), (LT, "I"), (SE4, "I"), (SK, "EI"), (UA, "E"))
+CZ._add_borders((AT, "EI"), (DE, "EI"), (PL, "EI"), (SK, "EI"))
+HU._add_borders((AT, "EI"), (HR, "E"), (RO, "EI"), (RS, "E"), (SK, "EI"), (UA, "E"))
+SK._add_borders((CZ, "EI"), (HU, "EI"), (PL, "EI"), (UA, "E"))
 
 
 ## Iberian Peninsula
@@ -514,16 +543,17 @@ PT._add_borders((ES, "I"))
 IT_NORD._add_borders((AT, "EI"), (CH, "E"), (FR, "EI"), (IT_CNOR, "I"), (SI, "EI"))
 IT_CNOR._add_borders((IT_CSUD, "I"), (IT_NORD, "I"), (IT_SARD, "I"))
 IT_CSUD._add_borders((IT_CNOR, "I"), (IT_SARD, "I"), (IT_SUD, "I"), (ME, "E"))
-IT_SUD._add_borders((GR, "E"), (IT_CSUD, "I"), (IT_SICI, "I"))
-IT_SICI._add_borders((IT_SUD, "I"), (MT, "I"))
+IT_SUD._add_borders((GR, "EI"), (IT_CSUD, "I"), (IT_CALA, "I"))
+IT_CALA._add_borders((IT_SUD, "I"), (IT_SICI, "I"))
+IT_SICI._add_borders((IT_CALA, "I"), (MT, "I"))
 IT_SARD._add_borders((FR_COR, "I"), (IT_CNOR, "I"), (IT_CSUD, "I"))
 
+
 SI._add_borders((AT, "EI"), (HR, "EI"), (IT_NORD, "EI"))
 RO._add_borders((BG, "E"), (HU, "EI"), (RS, "E"), (UA, "E"))
 HR._add_borders((BA, "E"), (HU, "E"), (RS, "E"), (SI, "EI"))
 BA._add_borders((HR, "E"), (ME, "E"), (RS, "E"))
 RS._add_borders(
-    (AL, "E"),
     (BA, "E"),
     (BG, "E"),
     (HR, "E"),
@@ -532,11 +562,12 @@ RS._add_borders(
     (MK, "E"),
     (RO, "E"),
 )
-ME._add_borders((AL, "E"), (BA, "E"), (IT_CSUD, "E"), (RS, "E"))
-BG._add_borders((GR, "E"), (MK, "E"), (RO, "E"), (RS, "E"), (TR, "E"))
-AL._add_borders((GR, "E"), (ME, "E"), (RS, "E"))
-MK._add_borders((BG, "E"), (GR, "E"), (RS, "E"))
-GR._add_borders((AL, "E"), (BG, "E"), (IT_SUD, "E"), (MK, "E"), (TR, "E"))
+ME._add_borders((AL, "E"), (BA, "E"), (IT_CSUD, "E"), (RS, "E"), (XK, "E"))
+BG._add_borders((GR, "EI"), (MK, "E"), (RO, "E"), (RS, "E"), (TR, "E"))
+AL._add_borders((GR, "E"), (ME, "E"), (XK, "E"))
+MK._add_borders((BG, "E"), (GR, "E"), (RS, "E"), (XK, "E"))
+GR._add_borders((AL, "E"), (BG, "EI"), (IT_SUD, "EI"), (MK, "E"), (TR, "E"))
+XK._add_borders((AL, "E"), (ME, "E"), (MK, "E"))
 
 
 ## South-Eastern Europe
