@@ -1,5 +1,5 @@
 from .frequency import Frequency
-from .timezone import UTC, CET, EET, WET, TRT, DEFAULT_TZ, local_tz
+from .timezone import UTC, CET, EET, WET, TRT, GAS_DAY, DEFAULT_TZ, local_tz
 from .resolution import Resolution
 from .utils import now, today, to_timezone, get_date, get_datetime
 
@@ -15,6 +15,7 @@ __all__ = [
     "EET",
     "WET",
     "TRT",
+    "GAS_DAY",
     # Various helpers
     "now",
     "today",
